package com.tourism.webadmin.back.dao;

import com.tourism.common.core.base.dao.BaseDaoMapper;
import com.tourism.webadmin.back.model.TourOrder;
import com.tourism.webadmin.back.model.TourUser;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import java.util.List;

/**
 * 旅游订单数据操作访问接口。
 *
 * @author 吃饭睡觉
 * @date 2024-09-06
 */
public interface TourOrderMapper extends BaseDaoMapper<TourOrder> {

    /**
     * 批量插入对象列表。
     *
     * @param tourOrderList 新增对象列表。
     */
    void insertList(List<TourOrder> tourOrderList);

    /**
     * 获取过滤后的对象列表。
     *
     * @param tourOrderFilter 主表过滤对象。
     * @param orderBy 排序字符串，order by从句的参数。
     * @return 对象列表。
     */
    List<TourOrder> getTourOrderList(
            @Param("tourOrderFilter") TourOrder tourOrderFilter, @Param("orderBy") String orderBy);

    @Select("select tu.show_name,tu.head_image_url,to1.create_time, to1.adult_number + to1.children_number as people_number from tour_user tu " +
            "inner join tour_order to1 on tu.user_id = to1.create_user_id " +
            "where to1.group_purchase_progress_id = #{projectId} and to1.type = 1 and to1.order_status != 3")
    List<TourUser> getTourUserList(@Param("projectId") Long projectId);
}
